{% load static from staticfiles %}
<img src="{% static 'img/2f.svg' %}"/>
<p>Point at these phrases if necessary:</p>
<div class="two-col">
  <p><big>我要到交通大學</big><br/><em>I want to go to NCTU</em></p>
  <p><big>我要到桃園機場</big><br/><em>I want to go to Taoyuan Airport</em></p>
  <p><big>我要到 ______________</big><br/><em>I want to go to ______________</em></p>
  <p><big>廁所在哪裡</big><br/><em>Where's the toilet?</em></p>
  <p><big>可以跟您借手機打電話嗎</big><br/><em>May I borrow your cellphone for a call?</em></p>
  <div class="two-col">
    <p><big>是</big><br/><em>Yes</em></p>
    <p><big>不是</big><br/><em>No</em></p>
  </div>
</div>
