{% extends "wafer/base.html" %}
{% load i18n %}
{% block title %}{{ object.name }} - {{ WAFER_CONFERENCE_NAME }}{% endblock %}
{% block content %}
<section class="wafer">
  <h1>{{ object.name }}</h1>
  <div>
    {{ object.notes_html|safe }}
  </div>
</section>
{% endblock %}
